@@ -10,6 +10,7 @@ from ploomber.clients.client import Client
 from ploomber.util import requires
 
 import re
+from pathlib import Path
 from urllib.parse import urlparse, urlunparse
 
 
@@ -143,6 +144,10 @@ class SQLAlchemyClient(Client):
         self._engine = None
         self.split_source = split_source
 
+        if self.flavor == "sqlite":
+            parent_folder = Path(self._uri_parsed.path[1:]).parent
+            parent_folder.mkdir(exist_ok=True, parents=True)
+
         self._connection = None
 
     @property
