@@ -2,17 +2,6 @@ import base64
 import json
 
 
-# FIXME: not using this, delete
-class JSONSerializer:
-    @staticmethod
-    def serialize(metadata):
-        return json.dumps(metadata)
-
-    @staticmethod
-    def deserialize(metadata_str):
-        return json.loads(metadata_str)
-
-
 class Base64Serializer:
     @staticmethod
     def serialize(metadata):
