@@ -65,6 +65,11 @@ class SQLScript(ClientMixin, Task):
 
     def load(self, limit=10):
         """Load this task's product in a pandas.DataFrame
+
+        Parameters
+        ----------
+        limit : int, default=10
+            How many records to load, defaults to 10
         """
         import pandas as pd
         return pd.read_sql(f'SELECT * FROM {self.product} LIMIT {int(limit)}',
@@ -377,6 +382,8 @@ class SQLUpload(ClientMixin, Task):
                     'file with extension: {}'.format(extension),
                     'pass the function directly in the '
                     'io_handler argument')
+        else:
+            read_fn = self.io_handler
 
         self._logger.info('Reading data...')
         df = read_fn(path)
