@@ -132,7 +132,13 @@ def callback_check(fn, available, allow_default=True):
     ploomber.exceptions.CallbackSignatureError
         When fn does not have the required signature
     """
+    # keep a copy of the original value because we'll modified it if this is
+    # a DottedPath
+    available_raw = available
+
     if isinstance(fn, DottedPath):
+        available = {**fn._spec.get_kwargs(), **available}
+
         if fn.callable is None:
             raise CallbackCheckAborted(
                 'Cannot check callback because function '
@@ -170,7 +176,7 @@ def callback_check(fn, available, allow_default=True):
                                      '{}'.format(fn_name, extra,
                                                  available_set))
 
-    return {k: v for k, v in available.items() if k in required}
+    return {k: v for k, v in available_raw.items() if k in required}
 
 
 def signature_check(fn, params, task_name):
